Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1040)

Unified Diff: Source/core/page/animation/AnimationBase.cpp

Issue 24921002: Make compositingState explicit (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: path for re-landing try #2 with removed unnecessary comment Created 7 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/page/FrameView.cpp ('k') | Source/core/page/animation/ImplicitAnimation.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/page/animation/AnimationBase.cpp
diff --git a/Source/core/page/animation/AnimationBase.cpp b/Source/core/page/animation/AnimationBase.cpp
index 40b7483e7a68984ee4f74cbe7466fefbcea145de..03ca1364b98648787f64ab384f02f4954391b915 100644
--- a/Source/core/page/animation/AnimationBase.cpp
+++ b/Source/core/page/animation/AnimationBase.cpp
@@ -555,8 +555,9 @@ void AnimationBase::freezeAtTime(double t)
else
m_pauseTime = m_startTime + t - m_animation->delay();
- // It is possible that m_isAccelerated is true and m_object->isComposited() is false, because of style change.
- if (m_object && m_object->isComposited() && isAccelerated())
+ // It is possible that m_isAccelerated is true and m_object->compositingState() is NotComposited, because of style change.
+ // So, both conditions need to be checked.
+ if (m_object && m_object->compositingState() == PaintsIntoOwnBacking && isAccelerated())
toRenderBoxModelObject(m_object)->suspendAnimations(m_pauseTime);
}
« no previous file with comments | « Source/core/page/FrameView.cpp ('k') | Source/core/page/animation/ImplicitAnimation.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698